@@ -111,17 +111,24 @@ sub _build_arg ($self) {
 
     my $class = $self->class;
 
-    my $last_arg;
+    my $next_arg = 0;    # 0 - any, 1 - min = 0, 2 - no arg
 
     if ( $class->can('cli_arg') && defined( my $cli_arg = $class->cli_arg ) ) {
         for my $cfg ( $cli_arg->@* ) {
-            die q[Can't have other arguments after slurpy argument] if $last_arg;
+            die q[Can't have other arguments after slurpy argument] if $next_arg == 2;
 
             my $arg = Pcore::Core::CLI::Arg->new($cfg);
 
+            die q[Can't have required argument after not mandatory argument] if $next_arg == 1 && $arg->min != 0;
+
             die qq[Argument "@{[$arg->name]}" is duplicated] if exists $index->{ $arg->name };
 
-            $last_arg = $arg->is_last;
+            if ( !$arg->max ) {    # slurpy arg
+                $next_arg = 2;
+            }
+            elsif ( $arg->min == 0 ) {
+                $next_arg = 1;
+            }
 
             push $args->@*, $arg;
 
@@ -269,8 +276,8 @@ sub _parse_opt ( $self, $argv ) {
 
     my $parser = Getopt::Long::Parser->new(
         config => [    #
-            'no_auto_abbrev',
-            'no_getopt_compat',
+            'auto_abbrev',
+            'no_getopt_compat',    # do not allow + to start options
             'gnu_compat',
             'no_require_order',
             'permute',
@@ -337,7 +344,7 @@ sub _parse_opt ( $self, $argv ) {
         }
     }
 
-    return $self->help_usage( [qq[unknown arguments]] ) if $parsed_args->@*;
+    return $self->help_usage( [qq[unexpected arguments]] ) if $parsed_args->@*;
 
     # validate cli
     my $class = $self->class;
@@ -371,36 +378,9 @@ sub _get_class_cmd ( $self, $class = undef ) {
 
 # HELP
 sub _help_class_abstract ( $self, $class = undef ) {
-    my $abstract;
-
     $class //= $self->class;
 
-    if ( $class->can('cli_abstract') ) {
-        $abstract = $class->cli_abstract;
-    }
-
-    if ( !defined $abstract ) {
-        my $path;
-
-        if ( $class eq 'main' ) {
-            $path = $PROC->{SCRIPT_PATH};
-        }
-        else {
-            $path = $INC{ $class =~ s[::][/]smgr . '.pm' };
-        }
-
-        my $content = P->file->read_bin($path);
-
-        if ( $content->$* =~ m[=head1\s+NAME\s*$class\s*-\s*([^\n]+)]smi ) {
-            $abstract = $1;
-        }
-    }
-
-    $abstract //= q[];
-
-    $abstract =~ s/\n+\z//sm;
-
-    return $abstract;
+    return $class->can('cli_abstract') ? $class->cli_abstract // q[] : q[];
 }
 
 sub _help_usage_string ($self) {
@@ -439,7 +419,6 @@ sub _help_alias ($self) {
     }
 }
 
-# TODO try to get help from POD =head DESCRIPTION
 sub _help ($self) {
     my $help;
 
@@ -553,9 +532,13 @@ sub help_usage ( $self, $invalid_options = undef ) {
 }
 
 sub help_version ($self) {
-    say $PROC->dist->name . q[ ], $PROC->dist->version, ', rev: ' . $PROC->dist->revision if $PROC->dist;
+    my $format_info = sub ($dist) {
+        return "@{[$dist->name]} @{[$dist->version]} @{[$dist->revision]} @{[$dist->build_date]}";
+    };
 
-    say 'Pcore ' . $PROC->pcore->version, ', rev: ' . $PROC->pcore->revision;
+    say $format_info->( $PROC->dist ) if $PROC->dist;
+
+    say $format_info->( $PROC->pcore ) if !$PROC->dist || $PROC->dist->name ne $PROC->pcore->name;
 
     exit 2;
 }
@@ -575,13 +558,13 @@ sub help_error ( $self, $msg ) {
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │ 46                   │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 89, 92, 150, 231,    │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 266, 327, 350, 413,  │                                                                                                                │
-## │      │ 476, 481, 485, 494   │                                                                                                                │
+## │    3 │ 89, 92, 157, 238,    │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 273, 334, 357, 393,  │                                                                                                                │
+## │      │ 455, 460, 464, 473   │                                                                                                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 340                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 347                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 374, 514, 542        │ NamingConventions::ProhibitAmbiguousNames - Ambiguously named variable "abstract"                              │
+## │    3 │ 493, 521             │ NamingConventions::ProhibitAmbiguousNames - Ambiguously named variable "abstract"                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
