@@ -2,15 +2,13 @@ package Pcore::Core::Exception;
 
 use Pcore qw[-export];
 
-BEGIN {
-    our @EXPORT_OK   = qw[croak cluck propagate try catch];
-    our %EXPORT_TAGS = ();
-    our @EXPORT      = @EXPORT_OK;
-}
-
 use Pcore::Core::Exception::Object;
 use Carp qw[];
 
+our @EXPORT_OK   = qw[croak cluck propagate try catch];
+our %EXPORT_TAGS = ();
+our @EXPORT      = @EXPORT_OK;
+
 our $IGNORE_ERRORS = 1;    # do not write errors to error log channel by default
 
 sub CORE_INIT {
@@ -21,9 +19,9 @@ sub CORE_INIT {
     # needed to properly destruct TEMP_DIR
     $SIG->{TERM} = AE::signal TERM => \&SIGTERM;
 
-    $SIG{__DIE__} = \&SIGDIE;    ## no critic qw(Variables::RequireLocalizedPunctuationVars)
+    $SIG{__DIE__} = \&SIGDIE;    ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
-    $SIG{__WARN__} = \&SIGWARN;  ## no critic qw(Variables::RequireLocalizedPunctuationVars)
+    $SIG{__WARN__} = \&SIGWARN;  ## no critic qw[Variables::RequireLocalizedPunctuationVars]
 
     *CORE::GLOBAL::die = \&GLOBAL_DIE;
 
@@ -79,7 +77,7 @@ sub SIGDIE {
 }
 
 sub SIGWARN {
-    my $e = Pcore::Core::Exception::Object->new_exception( $_[0], level => 'WARN', skip_frames => 1, trace => 0 );
+    my $e = Pcore::Core::Exception::Object->new_exception( $_[0], level => 'WARN', skip_frames => 1, trace => 1 );
 
     # fallback to standart behavior if exception wasn't created for some reasons
     unless ( defined $e ) {
@@ -110,7 +108,7 @@ sub GLOBAL_DIE {
 sub GLOBAL_WARN {
     my $msg = defined $_[0] ? $_[0] : defined $@ ? $@ : q[Warning: something's wrong];
 
-    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'WARN', skip_frames => 1, trace => 0, from_hook => 1 );
+    my $e = Pcore::Core::Exception::Object->new_exception( $msg, level => 'WARN', skip_frames => 1, trace => 1, from_hook => 1 );
 
     if ( defined $e ) {
         return CORE::warn $e;
@@ -183,7 +181,7 @@ sub try : prototype(&@) {
     my $failed = not eval {
         local $SIG{__DIE__} = \&SIGDIE;
 
-        $@ = $prev_error;    ## no critic qw(Variables::RequireLocalizedPunctuationVars) make previous $@ accesible inside eval, eval clean $@ before start
+        $@ = $prev_error;    ## no critic qw[Variables::RequireLocalizedPunctuationVars] make previous $@ accesible inside eval, eval clean $@ before start
 
         if ($wantarray) {
             @res = $try->();
@@ -215,7 +213,7 @@ sub try : prototype(&@) {
         }
 
         if ( $e->is_propagated ) {
-            $@ = q[];    ## no critic qw(Variables::RequireLocalizedPunctuationVars), clear $@ because handled propagated exception treat as not error
+            $@ = q[];    ## no critic qw[Variables::RequireLocalizedPunctuationVars], clear $@ because handled propagated exception treat as not error
 
             $e->propagate unless $e->_stop_propagate;
         }
