@@ -39,4 +39,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Guard
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
