@@ -3,7 +3,6 @@ package Pcore::Dist::Build::Release;
 use Pcore qw[-class];
 use Pod::Markdown;
 use CPAN::Meta;
-use Module::Metadata;
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
 
@@ -14,7 +13,7 @@ has bugfix => ( is => 'ro', isa => Bool, default => 0 );
 no Pcore;
 
 sub run ($self) {
-    if ( $self->dist->cfg->{dist}->{cpan} && !$self->dist->global_cfg || ( !$self->dist->global_cfg->{PAUSE}->{username} || !$self->dist->global_cfg->{PAUSE}->{password} ) ) {
+    if ( $self->dist->cfg->{dist}->{cpan} && !$self->dist->build->user_cfg || ( !$self->dist->build->user_cfg->{PAUSE}->{username} || !$self->dist->build->user_cfg->{PAUSE}->{password} ) ) {
         say 'You need to specify PAUSE credentials';
 
         return;
@@ -29,8 +28,8 @@ sub run ($self) {
     my $scm = $self->dist->scm->server;
 
     # check for uncommited changes
-    if ( $scm->cmd(qw[status -mard])->%* ) {
-        say 'Working copy has uncommited changes. Release is impossible.';
+    if ( $scm->cmd(qw[status -mardu --subrepos])->%* ) {
+        say 'Working copy or subrepos has uncommited changes or unknown files. Release is impossible.';
 
         return;
     }
@@ -53,7 +52,7 @@ sub run ($self) {
         $parts[1]++;
         $parts[2] = 0;
     }
-    else {
+    elsif ( $self->bugfix ) {
         $parts[2]++;
     }
 
@@ -71,22 +70,23 @@ sub run ($self) {
 
     return if P->term->prompt( 'Continue release process?', [qw[yes no]], enter => 1 ) ne 'yes';
 
-    # update release version in the main_module
-    my $main_module = P->file->read_bin( $self->dist->main_module_path );
-
-    unless ( $main_module->$* =~ s[^(\s*package\s+\w[\w\:\']*\s+)v?[\d._]+(\s*;)][$1$new_ver$2]sm ) {
+    # update release version in the main module
+    unless ( $self->dist->module->content->$* =~ s[^(\s*package\s+\w[\w\:\']*\s+)v?[\d._]+(\s*;)][$1$new_ver$2]sm ) {
         say 'Error updating version';
 
         return;
     }
 
-    P->file->write_bin( $self->dist->main_module_path, $main_module );
+    P->file->write_bin( $self->dist->module->path, $self->dist->module->content );
 
     # update working copy
     $self->dist->build->update;
 
+    # generate wiki
+    $self->dist->build->wiki->run if $self->dist->build->wiki;
+
     # commit
-    $scm->cmd( 'commit', qq[-m"stable $new_ver"] );
+    $scm->cmd( 'commit', qq[-m"stable $new_ver"], '--subrepos' );
 
     $scm->cmd( 'tag', '-f', 'stable', $new_ver );
 
@@ -102,7 +102,7 @@ sub _upload_to_cpan ($self) {
     say '.tgz created, now uploaded to CPAN';
 
   REDO:
-    my ( $status, $reason ) = $self->_upload( $self->dist->global_cfg->{PAUSE}->{username}, $self->dist->global_cfg->{PAUSE}->{password}, $tgz );
+    my ( $status, $reason ) = $self->_upload( $self->dist->build->user_cfg->{PAUSE}->{username}, $self->dist->build->user_cfg->{PAUSE}->{password}, $tgz );
 
     if ( $status == 200 ) {
         say qq[Upload to CPAN status: $reason];
@@ -196,7 +196,9 @@ sub _upload ( $self, $username, $password, $path ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 32                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 31                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    2 │ 16, 74, 105          │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
