@@ -156,7 +156,7 @@ sub compress ( $self, % ) {
     require BerkeleyDB;
 
     state $cache = do {
-        my $path = $PROC->{PCORE_SYS_DIR} . 'perl-compress.bdb';
+        my $path = $PROC->{PCORE_USER_DIR} . 'perl-compress.bdb';
 
         tie my %cache, 'BerkeleyDB::Hash', -Filename => $path, -Flags => BerkeleyDB::DB_CREATE();
 
