@@ -2,7 +2,9 @@ package Pcore::Util::Data;
 
 use Pcore;
 use Sort::Naturally qw[nsort];
-use Scalar::Util qw[blessed];    ## no critic qw(Modules::ProhibitEvilModules)
+use Scalar::Util qw[blessed];    ## no critic qw[Modules::ProhibitEvilModules]
+use URI::Escape::XS qw[];        ## no critic qw[Modules::ProhibitEvilModules]
+use WWW::Form::UrlEncoded::XS qw[];
 
 our $TOKEN = {
     serializer => {
@@ -55,10 +57,10 @@ sub encode {
 
     # encode
     if ( $args{to} eq 'PERL' ) {
-        require Data::Dumper;    ## no critic qw(Modules::ProhibitEvilModules)
+        require Data::Dumper;    ## no critic qw[Modules::ProhibitEvilModules]
 
         state $sort_keys = sub {
-            return [ nsort keys $_[0] ];
+            return [ nsort keys $_[0]->%* ];
         };
 
         local $Data::Dumper::Indent     = 0;
@@ -146,7 +148,7 @@ sub encode {
 
         state $xml_obj = XML::Hash::XS->new( $xml_args->%* );
 
-        my $root = [ keys $data ]->[0];
+        my $root = [ keys $data->%* ]->[0];
 
         $res = \$xml_obj->hash2xml( $data->{$root}, root => $root, indent => $args{readable} ? 4 : 0 );
     }
@@ -324,7 +326,7 @@ sub decode {
 
         P->text->decode( $data_ref->$* );
 
-        ## no critic qw(BuiltinFunctions::ProhibitStringyEval)
+        ## no critic qw[BuiltinFunctions::ProhibitStringyEval]
         $res = eval <<"CODE";
 package $ns;
 use Pcore qw[-config];
@@ -504,7 +506,7 @@ sub to_json {
         @_,
     );
 
-    require JSON::XS;    ## no critic qw(Modules::ProhibitEvilModules)
+    require JSON::XS;    ## no critic qw[Modules::ProhibitEvilModules]
 
     # create and configure JSON serializer object
     my $json;
@@ -549,7 +551,7 @@ sub from_json {
         @_,
     );
 
-    require JSON::XS;    ## no critic qw(Modules::ProhibitEvilModules)
+    require JSON::XS;    ## no critic qw[Modules::ProhibitEvilModules]
 
     # create and configure JSON deserializer object
     my $json;
@@ -649,7 +651,7 @@ sub from_ini {
 sub to_b64 {
     my $self = shift;
 
-    require MIME::Base64;    ## no critic qw(Modules::ProhibitEvilModules)
+    require MIME::Base64;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return MIME::Base64::encode_base64( $_[0], $_[1] );
 }
@@ -657,7 +659,7 @@ sub to_b64 {
 sub to_b64_url {
     my $self = shift;
 
-    require MIME::Base64;    ## no critic qw(Modules::ProhibitEvilModules)
+    require MIME::Base64;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return MIME::Base64::encode_base64url(@_);
 }
@@ -665,7 +667,7 @@ sub to_b64_url {
 sub from_b64 {
     my $self = shift;
 
-    require MIME::Base64;    ## no critic qw(Modules::ProhibitEvilModules)
+    require MIME::Base64;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return MIME::Base64::decode_base64(@_);
 }
@@ -673,7 +675,7 @@ sub from_b64 {
 sub from_b64_url {
     my $self = shift;
 
-    require MIME::Base64;    ## no critic qw(Modules::ProhibitEvilModules)
+    require MIME::Base64;    ## no critic qw[Modules::ProhibitEvilModules]
 
     return MIME::Base64::decode_base64url(@_);
 }
@@ -683,13 +685,9 @@ sub to_uri {
     my $self = shift;
 
     if ( ref $_[0] ) {
-        require WWW::Form::UrlEncoded::XS;
-
         return WWW::Form::UrlEncoded::XS::build_urlencoded( blessed $_[0] && $_[0]->isa('Pcore::Util::Hash::Multivalue') ? $_[0]->get_hash : $_[0] );
     }
     else {
-        require URI::Escape::XS;    ## no critic qw(Modules::ProhibitEvilModules)
-
         return URI::Escape::XS::encodeURIComponent( $_[0] );
     }
 }
@@ -702,15 +700,21 @@ sub from_uri {
         splice( @_, 1 ),
     );
 
-    require URI::Escape::XS;    ## no critic qw(Modules::ProhibitEvilModules)
-
     state $encodings;
 
     if ( defined wantarray ) {
         if ( $args{encoding} ) {
             $encodings->{ $args{encoding} } //= Encode::find_encoding( $args{encoding} );
 
-            return $encodings->{ $args{encoding} }->decode( URI::Escape::XS::decodeURIComponent( $_[0] ), Encode::FB_CROAK | Encode::LEAVE_SRC );
+            my $u = URI::Escape::XS::decodeURIComponent( $_[0] );
+
+            eval {    #
+                $u = $encodings->{ $args{encoding} }->decode( $u, Encode::FB_CROAK | Encode::LEAVE_SRC );
+            };
+
+            utf8::upgrade($u) if $@;
+
+            return $u;
         }
         else {
             return URI::Escape::XS::decodeURIComponent( $_[0] );
@@ -720,7 +724,15 @@ sub from_uri {
         if ( $args{encoding} ) {
             $encodings->{ $args{encoding} } //= Encode::find_encoding( $args{encoding} );
 
-            $_[0] = $encodings->{ $args{encoding} }->decode( URI::Escape::XS::decodeURIComponent( $_[0] ), Encode::FB_CROAK | Encode::LEAVE_SRC );
+            my $u = URI::Escape::XS::decodeURIComponent( $_[0] );
+
+            eval {    #
+                $u = $encodings->{ $args{encoding} }->decode( $u, Encode::FB_CROAK | Encode::LEAVE_SRC );
+            };
+
+            utf8::upgrade($u) if $@;
+
+            $_[0] = $u;
         }
         else {
             $_[0] = URI::Escape::XS::decodeURIComponent( $_[0] );
@@ -738,9 +750,7 @@ sub from_uri_query {
         splice( @_, 1 ),
     );
 
-    require WWW::Form::UrlEncoded::XS;
-
-    state $encoding;
+    state $encoding = {};
 
     $encoding->{ $args{encoding} } //= Encode::find_encoding( $args{encoding} ) if $args{encoding};
 
@@ -756,10 +766,22 @@ sub from_uri_query {
         if ( $args{encoding} ) {
 
             # decode key
-            $pair->[0] = $encoding->{ $args{encoding} }->decode( $pair->[0], Encode::FB_CROAK | Encode::LEAVE_SRC );
+            if ( defined $pair->[0] ) {
+                eval {    #
+                    $pair->[0] = $encoding->{ $args{encoding} }->decode( $pair->[0], Encode::FB_CROAK | Encode::LEAVE_SRC );
+                };
+
+                utf8::upgrade( $pair->[0] ) if $@;
+            }
 
             # decode value
-            $pair->[1] = $encoding->{ $args{encoding} }->decode( $pair->[1], Encode::FB_CROAK | Encode::LEAVE_SRC ) if defined $pair->[1];
+            if ( defined $pair->[1] ) {
+                eval {    #
+                    $pair->[1] = $encoding->{ $args{encoding} }->decode( $pair->[1], Encode::FB_CROAK | Encode::LEAVE_SRC );
+                };
+
+                utf8::upgrade( $pair->[1] ) if $@;
+            }
         }
 
         push $hash->{ $pair->[0] }->@*, $pair->[1];
@@ -795,11 +817,13 @@ has args => ( is => 'ro', isa => ArrayRef, required => 1 );
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │                      │ Subroutines::ProhibitExcessComplexity                                                                          │
-## │      │ 30                   │ * Subroutine "encode" with high complexity score (35)                                                          │
-## │      │ 237                  │ * Subroutine "decode" with high complexity score (31)                                                          │
+## │      │ 32                   │ * Subroutine "encode" with high complexity score (35)                                                          │
+## │      │ 239                  │ * Subroutine "decode" with high complexity score (31)                                                          │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 147, 370, 398, 400,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 402, 404             │                                                                                                                │
+## │    3 │ 63, 149, 151, 372,   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 400, 402, 404, 406   │                                                                                                                │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    3 │ 711, 729, 770, 779   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
